summaryrefslogtreecommitdiff
path: root/searx/search/processors
diff options
context:
space:
mode:
authorMarkus Heiser <markus.heiser@darmarIT.de>2021-06-08 10:56:18 +0000
committerGitHub <noreply@github.com>2021-06-08 10:56:18 +0000
commit5c5db719d2039d34aa1426bf7eb3e57055d4a54a (patch)
tree15a7a5e1a811f1366cdb49b69e35633afaf56114 /searx/search/processors
parent5f76238d5cd6f9c850d5237fe639ba2900fd3e6c (diff)
parent6f7b0d72c084845ea073a82a357c5e99cd41a85f (diff)
Merge pull request #97 from return42/drop-searx-admin
[docs] reorder blog articles
Diffstat (limited to 'searx/search/processors')
-rw-r--r--searx/search/processors/online_dictionary.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/searx/search/processors/online_dictionary.py b/searx/search/processors/online_dictionary.py
index 11ca0335d..72941d57a 100644
--- a/searx/search/processors/online_dictionary.py
+++ b/searx/search/processors/online_dictionary.py
@@ -12,9 +12,9 @@ from .online import OnlineProcessor
parser_re = re.compile('.*?([a-z]+)-([a-z]+) ([^ ]+)$', re.I)
class OnlineDictionaryProcessor(OnlineProcessor):
- """Processor class used by ``online_dictionnary`` engines."""
+ """Processor class used by ``online_dictionary`` engines."""
- engine_type = 'online_dictionnary'
+ engine_type = 'online_dictionary'
def get_params(self, search_query, engine_category):
params = super().get_params(search_query, engine_category)